﻿using System.Collections.Generic;
using System.Text;
using Newtonsoft.Json;

namespace NonaBGS.BGS {
    public class Objective {
        private string system;
        private string station;
        private string faction;

        private List<LogEntry> entries = new List<LogEntry>();

        [JsonIgnore]
        public List<LogEntry> LogEntries {
            get => entries;
            set => entries = value;
        }

        public int Matches(LogEntry e) {
            int match_count = 0;

            if (e.OnlyControllingFaction) {
                if (Faction == null || (e.Faction != Faction)) {
                    return 0;
                }
            }

            if (e.System != null && system != null &&
                e.System == system) {
                ++match_count;
            }

            if (e.Station != null && station != null &&
                e.Station == station) {
                ++match_count;
            }

            if (e.Faction != null && faction != null &&
                e.Faction == faction) {
                ++match_count;
            }

            return match_count;
        }

        public int CompareTo(Objective other) {
            return (other.System == System &&
                other.Station == Station &&
                other.Faction == Faction) ? 0 : -1;
        }

        public bool IsValid => System != null && Faction != null;

        public string System {
            get { return system; }
            set { system = value; }
        }

        public string Station {
            get { return station; }
            set { station = value; }
        }

        public string Faction {
            get { return faction; }
            set { faction = value; }
        }

        public override string ToString() {
            StringBuilder str = new StringBuilder();
            if (system != null && system.Length > 0) {
                str.AppendFormat("System: {0}", system);
            }
            if (station != null && station.Length > 0) {
                if (str.Length > 0) {
                    str.Append(", ");
                }
                str.AppendFormat("Station: {0}", station);
            }
            if (faction != null && faction.Length > 0) {
                if (str.Length > 0) {
                    str.Append(", ");
                }
                str.AppendFormat("Faction: {0}", faction);
            }
            return str.ToString();
        }

        public string ToShortString() {
            StringBuilder str = new StringBuilder();
            if (system != null && system.Length > 0) {
                str.AppendFormat("{0}", system);
            }
            if (station != null && station.Length > 0) {
                if (str.Length > 0) {
                    str.Append(", ");
                }
                str.AppendFormat("{0}", station);
            }
            return str.ToString();
        }
    }
}
